#
# spec file for package rime-plum-go
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#

Name:           rime-plum-go
Version:        1.0.3
Release:        2.1
Summary:        RIME's plum configuration manager in golang
License:        GPL-3.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/marguerite/rime-plum-go
Source1:        rime-plum-go-%{version}.tar.gz
Source2:        vendor.tar.zst
BuildRequires:  zstd
BuildRequires:  golang(API) >= 1.17

%description
Rime is an Traditional Chinese input method engine.
Its idea comes from ancient Chinese brush and carving art.
Mainly it's about to express your thinking with your keystrokes.

rime-plum-go is RIME's plum configuration manager in golang

%package -n rime-plum
Summary:        Rime's configuration manager
Group:          System/I18n/Chinese

%description -n rime-plum
Plum is rime's configuration manager in golang.

%prep
echo %{_builddir}
mkdir -p %{_builddir}/go/src/github.com/marguerite
tar -xf %{SOURCE1} -C %{_builddir}/go/src/github.com/marguerite
tar -xf %{SOURCE2} -C %{_builddir}/go/src/github.com/marguerite/rime-plum-go-%{version}/
cp -r %{_builddir}/go/src/github.com/marguerite/rime-plum-go-%{version}/vendor/* %{_builddir}/go/src/

%build
pushd %{_builddir}/go/src/github.com/marguerite/rime-plum-go-%{version}
export GOPATH=%{_builddir}/go
go build -ldflags "-buildid="
popd

%install
mkdir -p %{buildroot}%{_bindir}
install -m 0755 %{_builddir}/go/src/github.com/marguerite/rime-plum-go-%{version}/rime-plum-go %{buildroot}%{_bindir}/rime-plum

%files -n rime-plum
%{_bindir}/rime-plum

%changelog
* Sat Mar 15 2025 Marguerite Su <i@marguerite.su>
- update version 1.0.3
  * update go.mod to fix two CVEs:
  + CVE-2024-45337 golang.org/x/crypto 0.31 fix it
  + CVE-2025-21613 go-git v5.13.0 fix it
  * add emoji-cantonese to "extra" rule set
  (bsc#1235573, bsc#1234597)
* Thu Jan  2 2025 Cliff Zhao <qzhao@suse.com>
- Split rime-plum-go from brise:
  * go-git is rime-plum-go's component, it meet security issue of
    the argument injection vulnerability, when rime-plum-go deliver
    under brise's source code, it is hard to update seperately.
  * rime-plum-go is a separate project and has a different upstream.
  * I have done my best to keep the original code the same in
    respect of Marguerite's hard work.
  (CVE-2025-21613, bsc#1235573, CVE-2024-45337, bsc#1234597)
* Mon Sep  4 2023 Cliff Zhao <qzhao@suse.com>
- Update brise.spec:
  * Add Conflicts condition to insure brise could update successfully
    from brise binary rpm, for SUSE:SLE-SP6 update.
  * Replace rime-schema-all dependence to real package name to
    avoid 2 level of virtual packages when it installed.
* Sat Jun  3 2023 Marguerite Su <i@marguerite.su>
- update brise 20230603+git.5fdd2d6
  * replace io/ioutil usage
  * deprecate rime-jyutping with rime-cantonese
  * add rime-custom
* Mon May 29 2023 Marguerite Su <i@marguerite.su>
- update brise 20230528+git.cece251
  * rime-plum-go supports github's "main" default branch
  * brise data is updated to 20230528
* Tue May 25 2021 Marguerite Su <i@marguerite.su>
- don't install .bin files in build
* Tue May 25 2021 Marguerite Su <i@marguerite.su>
- update brise 20210525+git4f7fc2a
  * revamped rime-plum-go with CLI ui support via "--select"
    rime-plum-go is totally compatible with upstream plum and
    the go version respects "rime_dir" "rime_frontend" environment
    variables and "http_proxy"/"https_proxy" proxies.
  * brise data is updated to 20210525
* Sun May  9 2021 Fusion Future <qydwhotmail@gmail.com>
- revert "remove rime-plum in package brise and ready to move it into a new package for easier maintenance"
* Thu May  6 2021 Fusion Future <qydwhotmail@gmail.com>
- remove rime-plum in package brise and ready to move it into a new package for easier maintenance
* Sat Oct 10 2020 Marguerite Su <i@marguerite.su>
- split brise to rime-schema-*
* Sun Sep 27 2020 Marguerite Su <i@marguerite.su>
- update rime-plum-go.tar.xz, fix tw build
* Sat Jul 20 2019 Marguerite Su <i@marguerite.su>
- update 0.39+git20190120.8d5ec2e
  * brise was deprecated since plum came out. openSUSE still
    provides brise but it is just a collection of ":all"
    schema set fetched by plum. the version will just
    indicate the time when maintainer updates the package
    from now on, because every schema has a separate git
    repository and no way to get a version. but we'd better
    collect some major changes from these repositories and
    list here.
* Mon Mar 14 2016 qzhao@suse.com
- Make sure source code's LICENSE file install by default.
* Wed Mar  2 2016 i@marguerite.su
- Update to version 0.36+git20160221.7dbd56b
* Wed Aug 12 2015 i@marguerite.su
- update version 0.36+git20150729.5c8435e
* Sun Aug 10 2014 i@marguerite.su
- update version 0.35+git20140810
  * default.yaml: add switch 'ascii_punct' to switch on and off Chinese
    punctuations; add hotkey Control+. to toggle ascii_punct;
    add hotkey Control+h for BackSpace, Control+[ for Escape;
    clear unfinished input when switching off Chinese mode with Caps Lock;
    enable folded options in schema list, press space key to unfold.
  * essay.txt: replaces essay.kct in installed files; fix bugs.
  * symbols.yaml: /bdz for Chinese punctuations in vertical writing.
  * stroke.dict.yaml: adopt BSD license as approved by its original author.
  * combo_pinyin: silently ignore invalid chords.
  * luna_pinyin_fluency: input various numeric characters with /0 ~ /10.
  * luna_pinyin, terra_pinyin, emoji, stroke, zyenpheng: update tables.
* Sat Mar 15 2014 i@marguerite.su
- update version 0.33git20140315
  * symbols.yaml: rearranged symbol table by Patricivs.
  * emoji: more Emoji symbols; support tips and alternative spellings.
  * jyutping: include more Cantonese phrases.
  * essay.txt, luna_pinyin, terra_pinyin: lots of improvements.
  * many other bugfixes since then.
* Mon Nov 11 2013 i@marguerite.su
- update version 0.30
  * default.yaml, symbols.yaml: prefer middle dot U+00B7 to U+30FB.
  * bopomofo_tw: bopomofo, output in Taiwan standard.
  * jyutping: include more characters.
  * luna_pinyin_simp: enable hotkey Control+Shift+4 to toggle
    simplified/traditional Chinese mode.
  * essay.txt, luna_pinyin, terra_pinyin: lots of improvements.
* Sat Jun 29 2013 i@marguerite.su
- update version 0.22
  * essay.txt, luna_pinyin, terra_pinyin: lots of bug-fixes.
  * wubi86: auto-commit complete words. (max_code_length: 4)
  * luna_pinyin*: enable user created custom_phrase.txt (rime>=0.9.9)
* Fri Feb  1 2013 i@marguerite.su
- although this package only have a /usr/share/rime-data,
  but it need building, 32-bit and 64-bit results are different.
  So remove BuildArch: noarch tag to fix ibus/fcitx-rime crash.
* Thu Oct 11 2012 i@marguerite.su
- update version 0.13
  * install data files from a separate package.
  * update: luna_pinyin, terra_pinyin, jyutping tables.
  * update: essay database.
  * new schema: emoji.
* Sat Jul 21 2012 i@marguerite.su
- initial version 0.9.2
  * chord-typing support: combine multiple keys to compose a syllable at once.
  * configuration: global page_size setting.
  * inline mode: extend the API to support inline mode.
  * table translator: add option to filter candidates by character set.
  * user dictionary: automatic recovery for corrupted databases.
  * user dictionary: fixed a bug that was responsible for missing user phrases.
  * rime_deployer: a utility program to prepare Rime's workspace.
  * rime_dict_manager: a utility program to import/export user dictionaries.
  * librime package: include 'brise', a collection of preset schemata in the package.
  * new schema: Middle Chinese Phonetic Transcription.
  * new schema: IPA input method in X-SAMPA.
